@@ -1,5 +1,5 @@
 from .effects import _blur, _rotate, _ascify, _caption1, _caption2, _crop, _resize, _cropcircle, _pixelate, _saturate
-from .effects import _deepfry, _flip, _mirror, _invert, _emojioverlay
+from .effects import _deepfry, _flip, _mirror, _invert, _emojioverlay, _triggered
 from PIL.Image import Image
 
 
@@ -19,13 +19,13 @@ class EffectsCreator:
         '''makes ascii art from given text'''
         return _ascify._ascify.renderimage(text)
 
-    def caption1(self, image: str, text: str = 'text here') -> Image:
+    def caption1(self, image: str, text: str = 'text here', _font_size_ratio_mul: float = 1.0) -> Image:
         '''adds given text to the image on the top side'''
-        return _caption1._caption1.renderimage(image, text)
+        return _caption1._caption1.renderimage(image, text, _font_size_ratio_mul)
 
-    def caption2(self, image: str, text: str = 'text here') -> Image:
+    def caption2(self, image: str, text: str = 'text here', _font_size_ratio_mul: float = 1.0) -> Image:
         '''adds given text to the image on the bottom side'''
-        return _caption2._caption2.renderimage(image, text)
+        return _caption2._caption2.renderimage(image, text, _font_size_ratio_mul)
 
     def crop(self, image: str) -> Image:
         '''crops image automactically in 1:1 ratio'''
@@ -70,3 +70,7 @@ class EffectsCreator:
     def emojioverlay(self, image: str, emoji: str, alpha: int = 100) -> Image:
         '''Overlays an image with an emoji'''
         return _emojioverlay._emojioverlay.renderimage(image, emoji, alpha)
+
+    def triggered(self, image: str) -> Image:
+        '''makes triggered meme.'''
+        return _triggered._triggered.renderimage(image)
